import { rawlist } from "@inquirer/prompts";
import { BOILERPLATE_OPTIONS } from "./constants.js";
export const PACKAGE_MANAGERS = ["npm", "yarn", "pnpm"];
export const isPackageManager = (value) => {
    return PACKAGE_MANAGERS.includes(value);
};
const PACKAGE_MANAGER_COMMANDS = {
    install: {
        npm: "npm install",
        yarn: "yarn",
        pnpm: "pnpm install",
    },
    add: {
        npm: "npm install",
        yarn: "yarn add",
        pnpm: "pnpm add",
    },
    run: {
        npm: "npx",
        yarn: "yarn",
        pnpm: "pnpm",
    },
};
export const getCommand = (command, packageManager, args) => {
    const pkgManagerCommand = PACKAGE_MANAGER_COMMANDS[command][packageManager];
    if (!args) {
        return pkgManagerCommand;
    }
    return `${pkgManagerCommand} ${args.join(" ")}`;
};
const askIntegrationLevel = async (boilerplate) => {
    return await rawlist({
        message: `What level will this integration be installed on?`,
        choices: [
            {
                name: boilerplate.includes(BOILERPLATE_OPTIONS.build)
                    ? "site (recommended for Build Event Handlers)"
                    : "site",
                value: "site",
            },
            {
                name: boilerplate.includes(BOILERPLATE_OPTIONS.connector)
                    ? "team (required for Connectors)"
                    : "team",
                value: "team",
            },
            { name: "team-and-site", value: "team-and-site" },
        ],
    });
};
export const decideIntegrationLevel = async (boilerplate) => {
    if (boilerplate.length === 1) {
        if (boilerplate[0] === BOILERPLATE_OPTIONS.build) {
            return "site";
        }
        else if (boilerplate[0] === BOILERPLATE_OPTIONS.connector) {
            return "team";
        }
        else {
            return await askIntegrationLevel(boilerplate);
        }
    }
    else {
        if (boilerplate.includes(BOILERPLATE_OPTIONS.build) &&
            boilerplate.includes(BOILERPLATE_OPTIONS.connector)) {
            return "team-and-site";
        }
        else {
            return await askIntegrationLevel(boilerplate);
        }
    }
};
